/******************************************************************************
* Copyright (C) 2004 - 2020 Xilinx, Inc.  All rights reserved.
* Copyright (C) 2023 Advanced Micro Devices, Inc. All Rights Reserved.
* SPDX-License-Identifier: MIT
******************************************************************************/

/*****************************************************************************/
/**
*
* @file microblaze_exceptions_g.h
*
* This file contains the exception handling information for the MicroBlaze
* processor. This file is usually generated by LibGen.
*
* <pre>
* MODIFICATION HISTORY:
*
* Ver   Date     Changes
* ----- -------- -----------------------------------------------
* 1.00a 06/24/04 First release
* </pre>
*
******************************************************************************/
#ifndef MICROBLAZE_EXCEPTIONS_G_H /**< prevent circular inclusions */
#define MICROBLAZE_EXCEPTIONS_G_H /**< by using protection macros */

#ifdef __cplusplus
extern "C" {
#endif

#define MICROBLAZE_EXCEPTIONS_ENABLED   1 /**< exceptions are enabled in
                                               the processor */

#ifdef __cplusplus
}
#endif

#endif /* end of protection macro */
